@@ -1,3 +1,4 @@
+import hashlib
 import os
 from dataclasses import dataclass
 from itertools import chain, starmap
@@ -14,12 +15,19 @@ from vcr.serialize import deserialize
 try:
     # VCR.py >=5
     from vcr.cassette import CassetteNotFoundError
-except ImportError:
+except ImportError:  # pragma: no cover
     # VCR.py <5
     CassetteNotFoundError = ValueError
 
 from .utils import ConfigType, merge_kwargs, unique, unpack
 
+try:
+    # Try to get max filename length on Unix-like systems
+    MAX_FILENAME_LEN = os.pathconf(".", "PC_NAME_MAX")
+except (AttributeError, ValueError, OSError):
+    # Fallback for Windows or unsupported systems
+    MAX_FILENAME_LEN = 255
+
 
 def load_cassette(cassette_path: str, serializer: ModuleType) -> Tuple[List, List]:
     try:
@@ -63,6 +71,14 @@ def use_cassette(
 ) -> CassetteContextDecorator:
     """Create a VCR instance and return an appropriate context manager for the given cassette configuration."""
     merged_config = merge_kwargs(config, markers)
+
+    # Check `default_cassette` to prevent it from being too long.
+    suffix = merged_config.get("serializer", ".yaml")
+    if len(default_cassette) + len(suffix) > MAX_FILENAME_LEN:
+        hash_part = hashlib.md5(default_cassette.encode()).hexdigest()
+        prefix = default_cassette[: MAX_FILENAME_LEN - len(suffix) - len(hash_part) - 3]
+        default_cassette = f"{prefix}...{hash_part}"
+
     if "record_mode" in merged_config:
         record_mode = merged_config["record_mode"]
     path_transformer = get_path_transformer(merged_config)
